#
# spec file for package perl-PPIx-QuoteLike
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name PPIx-QuoteLike
Name:           perl-PPIx-QuoteLike
Version:        0.023
Release:        1.12
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Parse Perl string literals and string-literal-like things
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/W/WY/WYANT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(PPI::Document) >= 1.238
BuildRequires:  perl(PPI::Dumper) >= 1.238
BuildRequires:  perl(Readonly)
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(PPI::Document) >= 1.238
Requires:       perl(PPI::Dumper) >= 1.238
Requires:       perl(Readonly)
%{perl_requires}

%description
This Perl class parses Perl string literals and things that are reasonably
like string literals. Its real reason for being is to find interpolated
variables for Perl::Critic policies and similar code.

The parse is fairly straightforward, and a little poking around with
_eg/pqldump_ should show how it normally goes.

But there is at least one quote-like thing that probably needs some
explanation.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README

%changelog
* Sat Sep 17 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.023
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.023		2022-09-16	T. R. Wyant
    Update discouragement notice for variables(), and add a TODO in
    t/variables.t for why.
    Correct normalization of ${^FOO} for PPI. If the caret is present
    the braces are not removed.
* Sat Apr 16 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.022
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.022		2022-04-15	T. R. Wyant
    Remove 'postderef' argument to new().  Postfix dereference is always
    recognized.
* Wed Apr  6 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.021
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.021		2022-04-03	T. R. Wyant
    Recognize postfix deref in '@{[ ... ]}' for determining minimum Perl
    version.  This recognizes all forms of postfix dereference,
    including ->%%*, ->&*, and ->**.  NOTE that for now this remains a
    PPIx::QuoteLike::Token::Interpolation.
    Require PPI 1.238 for postfix deref support, and prune code that
    dealt with PPI's old behavior.
    Postfix %%*, &*, and ** do not interpolate.
    Correct perl_version_introduced() for interpolated postfix scalar
    deref.
* Fri Mar 18 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.020
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.020		2022-03-17	T. R. Wyant
    Correct and optimize the computation of logical column position (the
    one that takes account of tabs).
* Tue Nov 16 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.019
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.019		2021-11-15	T. R. Wyant
    Add CONTRIBUTING file.
    Try to quell weird Win32 test failures which seem to occur only in
    tests where I am using 'use open' to put the standard handles into
    UTF-8 mode. The fix (I hope) is to do this to the Test::Harness
    handles at run time instead of to the standard handles at compile
    time.
* Sat Oct 23 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.018
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.018		2021-10-22	T. R. Wyant
    Argument postderef is now fatal.
    Correct generation of 'provides' metadata.  Thanks to Favio Poletti
    for blogging
    https://github.polettix.it/ETOOBUSY/2021/06/15/the-real-pause-workaround/,
    and ultimately to Joel Berger for the pointer to
    https://metacpan.org/pod/CPAN::Meta::Spec#no_index
* Sat Apr 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.017
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.017		2021-04-16	T. R. Wyant
    All uses of the postderef argument to new() now warn.
* Sat Mar 27 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.016
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.016		2021-03-26	T. R. Wyant
    Add rt.cpan.org back to bug reporting methods. Long live RT!
    Get prerequisites up to snuff, and add xt/author/prereq.t to ensure
    they stay that way.
    Refactor authortest into three, so I do not have to generate stub
    files to test without optional modules.
* Sat Feb  6 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.015
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.015		2021-02-05	T. R. Wyant
    Handle <<\EOD and <<~\EOD, which are equivalent to <<'EOD' and
    <<~'EOD', respectively.
    Recognize indented here documents. Thanks to Olaf Alders (oalders)
    for alerting me to this omission.
* Fri Jan 15 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.014
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.014		2021-01-14	T. R. Wyant
    Add Travis CI testing.
    Use GitHub as bug tracker. R.I.P. rt.cpan.org.
* Sat Oct 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.013
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.013		2020-10-09	T. R. Wyant
    Warn on first use of attribute 'postderef'.
* Wed Jul 29 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.012
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.012		2020-07-28	T. R. Wyant
    Remove prototypes from testing subroutines defined in t/*.t.
* Wed Apr  1 2020 <timueller+perl@suse.de>
- updated to 0.011
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.011		2020-03-31	T. R. Wyant
    Normalize interpolation before feeding to PPI. This produces a
    more-easily-analyzed PPI parse.
    The ->variables() method is now discouraged. It was written to support
    Perl::Critic::Policy::Variables::ProhibitUnusedVarsStricter, but turned
    out to be inadequate for the job.
    Deprecate new() argument postderef. At this stage it is only
    documented as deprecated. In the first release after October 1 2020
    it will warn on the first use. Eventually it will be retracted, and
    postfix dereferences will always be recognized. This is the default
    behavior now.
    Correct bracket matchers to accept multiple lines. This was, in some
    cases, causing interpolations to be misclassified as unknown tokens.
* Tue Mar 10 2020 <timueller+perl@suse.de>
- updated to 0.010
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.010		2020-03-09	T. R. Wyant
    Remove redundant and poorly-performing code introduced in version
    0.009.
* Fri Feb 28 2020 <timueller+perl@suse.de>
- updated to 0.009
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.009		2020-02-27	T. R. Wyant
    Add new() argument index_locations which causes locations to be
    indexed during the parse. This defaults based on whether a location
    argument was provided, and whether the string being parsed is a
    PPI::Element.
    Add method statement(), which returns the PPI statement containing
    the string element, or nothing if none.
    Add PPI::Element location methods, to wit: location(),
    column_number(), line_number(), logical_filename(),
    logical_line_number(), and visual_column_number().
    Add PPIx::QuoteLike::Utils::is_ppi_quotelike_element() which returns
    true if the argument is a PPI::Element of interest to us.
    All objects now have a variables() method inherited from
    PPIx::QuoteLike::Token. This method returns nothing unless
    overridden. It was added to eliminate $elem->can( 'variables' )
    ad-hocery.
    Eliminate redirections in POD URL links
* Sat Aug 17 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.008
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.008		2019-08-16	T. R. Wyant
    Fix broken POD links, and add test to ensure they stay fixed.
* Sat Jun  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.007
  see /usr/share/doc/packages/perl-PPIx-QuoteLike/Changes
  0.007		2019-05-31	T. R. Wyant
    Prohibit interpolation inside \N{...}.
    Fix error message in eg/pqldump
    Allow PPIx::QuoteLike::Utils::__variables() to take a PPI::Element
    (rather than PPI::Node), PPIx::Regexp::Element, PPIx::QuoteLike, or
    PPIx::QuoteLike::Token.
    Add eg/variables
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- initial package 0.006
  * created by cpanspec 1.78.09
